@@ -1,7 +1,7 @@
 pub(crate) mod cf;
 pub(crate) mod ec2;
 
-pub(crate) use ec2::regions;
+pub(crate) use ec2::get_all_regions;
 
 pub(crate) use cf::CfResources;
 pub(crate) use ec2::Ec2Resources;
